Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Caps ¶
type Caps struct {
Usage uint16
UsagePage uint16
// Report lengths
InputLen int
OutputLen int
FeatureLen int
NumLinkCollectionNodes int
NumInputButtonCaps int
NumInputValueCaps int
NumInputDataIndices int
NumOutputButtonCaps int
NumOutputValueCaps int
NumOutputDataIndices int
NumFeatureButtonCaps int
NumFeatureValueCaps int
NumFeatureDataIndices int
}
type Device ¶
Device is a HID device that statisfies io.ReadWriteCloser.
func (*Device) DeviceInfo ¶
func (d *Device) DeviceInfo() (*DeviceInfo, error)
func (*Device) SetOutputReport ¶
type DeviceInfo ¶
func SerialNo ¶
func SerialNo(sno string) ([]*DeviceInfo, error)
SerialNo finds accessible devices having the specified serial number.
func Stat ¶
func Stat(name string) (*DeviceInfo, error)
Stat returns device info from the specified path.
func VendorDevices ¶
func VendorDevices(vendor uint16, products ...uint16) ([]*DeviceInfo, error)
VendorDevices finds accessible devices having the specified vendor and product IDs.
Click to show internal directories.
Click to hide internal directories.